@@ -10,7 +10,7 @@ WIDGET_HELP_PATH = (
     # You still need to build help pages using
     # make htmlhelp
     # inside doc folder
-    ("{DEVELOP_ROOT}/doc/build/htmlhelp/widgets.html", None),
+    ("{DEVELOP_ROOT}/doc/build/html/widgets.html", None),
     # Online documentation url, used when the local documentation is available.
     # Url should point to a page with a section Widgets. This section should
     # includes links to documentation pages of each widget. Matching is
